@@ -1,5 +1,5 @@
 package DBIx::Class::Helper::ResultSet::Explain;
-$DBIx::Class::Helper::ResultSet::Explain::VERSION = '2.032000';
+$DBIx::Class::Helper::ResultSet::Explain::VERSION = '2.037000';
 # ABSTRACT: Get query plan for a ResultSet
 
 use strict;
@@ -114,11 +114,11 @@ to your entire schema.
      0,
      "Init",
      0,
-     11,
+     10,
      0,
-     "",
-     "00",
-     undef
+     undef,
+     0,
+     undef,
    ],
    [
      1,
@@ -127,8 +127,8 @@ to your entire schema.
      3,
      0,
      4,
-     "00",
-     undef
+     0,
+     undef,
    ],
    [
      2,
@@ -136,9 +136,9 @@ to your entire schema.
      0,
      9,
      0,
-     "",
-     "00",
-     undef
+     undef,
+     0,
+     undef,
    ],
    [
      3,
@@ -146,9 +146,9 @@ to your entire schema.
      0,
      1,
      0,
-     "",
-     "00",
-     undef
+     undef,
+     0,
+     undef,
    ],
    [
      4,
@@ -156,9 +156,9 @@ to your entire schema.
      0,
      1,
      2,
-     "",
-     "00",
-     undef
+     undef,
+     0,
+     undef,
    ],
    [
      5,
@@ -166,9 +166,9 @@ to your entire schema.
      0,
      2,
      3,
-     "",
-     "00",
-     undef
+     undef,
+     0,
+     undef,
    ],
    [
      6,
@@ -176,9 +176,9 @@ to your entire schema.
      0,
      3,
      4,
-     "",
-     "00",
-     undef
+     undef,
+     0,
+     undef,
    ],
    [
      7,
@@ -186,9 +186,9 @@ to your entire schema.
      1,
      4,
      0,
-     "",
-     "00",
-     undef
+     undef,
+     0,
+     undef,
    ],
    [
      8,
@@ -196,74 +196,54 @@ to your entire schema.
      0,
      3,
      0,
-     "",
-     "01",
-     undef
+     undef,
+     1,
+     undef,
    ],
    [
      9,
-     "Close",
-     0,
-     0,
-     0,
-     "",
-     "00",
-     undef
-   ],
-   [
-     10,
      "Halt",
      0,
      0,
      0,
-     "",
-     "00",
-     undef
+     undef,
+     0,
+     undef,
    ],
    [
-     11,
+     10,
      "Transaction",
      0,
      0,
-     16,
+     17,
      0,
-     "01",
-     undef
+     1,
+     undef,
    ],
    [
-     12,
-     "TableLock",
-     0,
-     3,
-     0,
-     "Gnarly",
-     "00",
-     undef
-   ],
-   [
-     13,
+     11,
      "Goto",
      0,
      1,
      0,
-     "",
-     "00",
-     undef
-   ]
+     undef,
+     0,
+     undef,
+   ],
  ]
 
 =head2 Pg
 
  [
    [
-     "Seq Scan on \"Gnarly\" me  (cost=0.00..16.20 rows=620 width=100) (actual time=0.001..0.001 rows=0 loops=1)"
+     "Seq Scan on \"Gnarly\" me  (cost=0.00..16.20 rows=620 width=100) (actual time=0.003..0.003 rows=0 loops=1)",
    ],
    [
-     "Planning time: 0.213 ms"
+     "Planning time: 0.102 ms",
    ],
    [
-     "Execution time: 0.015 ms"
-   ]
+     "Execution time: 0.023 ms",
+   ],
  ]
 
 =head2 mysql
@@ -279,9 +259,9 @@ to your entire schema.
      undef,
      undef,
      1,
-     "100.00",
-     ""
-   ]
+     100,
+     "",
+   ],
  ]
 
 =head1 AUTHOR
@@ -290,7 +270,7 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2024 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
